@@ -44,13 +44,14 @@ def caput(pvname, value, wait=False, timeout=60.0, tramp=None, bak=backUpVals):
                              timeout=timeout)
     else:
         rampYourself = True
+        fus = pvname.rfind('_') + 1
         # If this looks like a GAIN channel, look for TRAMP channel
-        if pvname[-4:] == 'GAIN':
-            try:
-                trch = pvname[:-4] + 'TRAMP'
-                tbak = epics.caget(pvname=trch, timeout=timeout)
+        if pvname[fus:] in ['GAIN', 'OFFSET']:
+            trch = pvname[:-4] + 'TRAMP'
+            tbak = epics.caget(pvname=trch, timeout=0.2)
+            if tbak is not None:
                 rampYourself = False
-            except BaseException:
+            else:
                 rampYourself = True
         if not rampYourself:
             epics.caput(pvname=trch, value=tramp, wait=wait, timeout=timeout)
