@@ -44,7 +44,10 @@ def writeMatrix(basename, mat, firstRow=1, firstCol=1, suffix=None,
                         cols=mat.shape[1], firstRow=firstRow,
                         firstCol=firstCol, suffix=suffix)
     if basename not in bak:
-        bak[basename] = {'type': 'matrix', 'name': basename, 'suffix': suffix,
+        name = (basename + '_' + str(firstRow) + '_' + str(firstCol)
+                + '_' + str(mat.shape[0]) + '_' + str(mat.shape[1]))
+        bak[basename] = {'type': 'matrix', 'suffix': suffix,
+                         'name': name,
                          'value': curMat, 'firstRow': firstRow,
                          'firstCol': firstCol, 'tramp': tramp, 'sno': len(bak)}
     if tramp is not None:
